@@ -15,21 +15,46 @@ import unittest
 from cliff import columns
 
 
-class FauxColumn(columns.FormattableColumn):
-
+class FauxColumn(columns.FormattableColumn[str | list[str]]):
     def human_readable(self):
-        return u'I made this string myself: {}'.format(self._value)
+        return f'I made this string myself: {self._value}'
 
 
 class TestColumns(unittest.TestCase):
-
-    def test_faux_column_machine(self):
+    def test_machine_readable(self):
         c = FauxColumn(['list', 'of', 'values'])
         self.assertEqual(['list', 'of', 'values'], c.machine_readable())
 
-    def test_faux_column_human(self):
+    def test_human_readable(self):
         c = FauxColumn(['list', 'of', 'values'])
         self.assertEqual(
-            u"I made this string myself: ['list', 'of', 'values']",
+            "I made this string myself: ['list', 'of', 'values']",
             c.human_readable(),
         )
+
+    def test_str(self):
+        c = FauxColumn(['list', 'of', 'values'])
+        self.assertEqual(
+            "I made this string myself: ['list', 'of', 'values']",
+            str(c),
+        )
+
+    def test_repr(self):
+        c = FauxColumn(['list', 'of', 'values'])
+        self.assertEqual(
+            "FauxColumn(['list', 'of', 'values'])",
+            repr(c),
+        )
+
+    def test_sorting(self):
+        cols = [
+            FauxColumn('foo'),
+            FauxColumn('bar'),
+            FauxColumn('baz'),
+            FauxColumn('foo'),
+        ]
+        cols.sort()
+        self.assertEqual(
+            ['bar', 'baz', 'foo', 'foo'],
+            [c.machine_readable() for c in cols],
+        )
